@@ -54,7 +54,8 @@ class ReviewForm(AbstractWidget):
 @dataclass
 class ViewerElement(AbstractWidget):
     search_mask: str
-    link: str | None
+    position: str | None
+    relative_to: str | None
 
 
 @dataclass
