@@ -1,14 +1,17 @@
 from qtpy import QtWidgets
 
 from ..runtime.appdata import AppData
+from ..runtime import config
 from ..io.output import get_checkboxes
 from .AbstractWidget import AbstractWidget
 
 
 class ReviewForm(QtWidgets.QGroupBox, AbstractWidget):
-    def __init__(self, rd: AppData, parent=None):
-        self.cfg = rd.config.review_form
-        super().__init__(rd=rd, cfg=self.cfg, parent=parent)
+    def __init__(self, rd: AppData, cfg: config.ReviewForm, parent=None):
+        super().__init__(cfg=cfg, parent=parent)
+
+        self.rd = rd
+        self.cfg = cfg
 
         self.setTitle('Review Form')
         self.setSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
@@ -19,8 +22,6 @@ class ReviewForm(QtWidgets.QGroupBox, AbstractWidget):
         # create a multi-line text editor for writing comments
         self._comments_widget = QtWidgets.QTextEdit()
 
-        self.init_ui()
-
     @staticmethod
     def create_checkbox_widgets(checkboxes: dict[str, str] | None) -> dict[str, QtWidgets.QCheckBox]:
         if checkboxes is None:
@@ -49,7 +50,8 @@ class ReviewForm(QtWidgets.QGroupBox, AbstractWidget):
         for cname, widget in self._checkboxes.items():
             widget.setChecked(self.rd.df.at[self.rd.id, cname])
 
-    def load_project(self):
+    def activate(self):
         self._checkboxes = self.create_checkbox_widgets(get_checkboxes(self.rd.df, self.cfg.checkboxes))
+        self.reset_layout()
 
-        super().load_project()
+        super().activate()
