@@ -1,7 +1,6 @@
 from .DataViewer import *
 
-from .ImageCutout import *
-from .Spec2D import *
+from .Image2D import *
 from .Spec1D import *
 from .Eazy import *
 
